whois

package module
v0.0.0-...-cfb48ef Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 5, 2025 License: Apache-2.0 Imports: 10 Imported by: 0

README

Whois

License GoDoc Go Report Card Build Status Code Cover

Whois is a simple Go module for domain and ip whois information query.

Overview

All of domain, IP include IPv4 and IPv6, ASN are supported.

You can directly using the binary distributions whois, follow whois release tool.

Or you can do development by using this golang module as below.

Installation

go get -u github.com/likexian/whois

Importing

import (
    "github.com/likexian/whois"
)

Documentation

Visit the docs on GoDoc

Example

whois query for domain
result, err := whois.Whois("likexian.com")
if err == nil {
    fmt.Println(result)
}
whois query for IPv6
result, err := whois.Whois("2001:dc7::1")
if err == nil {
    fmt.Println(result)
}
whois query for IPv4
result, err := whois.Whois("1.1.1.1")
if err == nil {
    fmt.Println(result)
}
whois query for ASN
// or whois.Whois("AS60614")
result, err := whois.Whois("60614")
if err == nil {
    fmt.Println(result)
}

Whois information parsing

Please refer to whois-parser

License

Copyright 2014-2024 Li Kexian

Licensed under the Apache License 2.0

Donation

If this project is helpful, please share it with friends.

If you want to thank me, you can give me a cup of coffee.

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrDomainEmpty is domain is an empty string
	ErrDomainEmpty = errors.New("whois: domain is empty")

	// ErrWhoisServerNotFound is no whois server found
	ErrWhoisServerNotFound = errors.New("whois: no whois server found for domain")
)
var DefaultClient = NewClient()

Functions

func Author

func Author() string

func CreateSOCKS5HDialer

func CreateSOCKS5HDialer(proxyURL string) (proxy.Dialer, error)

CreateSOCKS5HDialer parses socks5h://user:pass@host:port

func IsASN

func IsASN(s string) bool

func License

func License() string

func Version

func Version() string

func Whois

func Whois(domain string, servers ...string) (string, error)

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func NewClient

func NewClient() *Client

func (*Client) SetDialer

func (c *Client) SetDialer(dialer proxy.Dialer) *Client

func (*Client) SetDisableReferral

func (c *Client) SetDisableReferral(disabled bool) *Client

func (*Client) SetDisableReferralChain

func (c *Client) SetDisableReferralChain(disabled bool) *Client

func (*Client) SetDisableStats

func (c *Client) SetDisableStats(disabled bool) *Client

func (*Client) SetTimeout

func (c *Client) SetTimeout(timeout time.Duration) *Client

func (*Client) Whois

func (c *Client) Whois(domain string, servers ...string) (string, error)

Directories

Path Synopsis
cmd
whois command

Jump to